==> codeready-workspaces-2.4.0-GA-crwctl-sources.tar.gz: crwctl/lib/commands/server/debug.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2019 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const flags_1 = require("@oclif/parser/lib/flags");
const Listr = require("listr");
const common_flags_1 = require("../../common-flags");
const che_1 = require("../../tasks/che");
const api_1 = require("../../tasks/platforms/api");
class Debug extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Debug);
            const ctx = {};
            const cheTasks = new che_1.CheTasks(flags);
            const apiTasks = new api_1.ApiTasks();
            const tasks = new Listr([], { renderer: flags['listr-renderer'] });
            tasks.add(apiTasks.testApiTasks(flags, this));
            tasks.add(cheTasks.verifyCheNamespaceExistsTask(flags, this));
            tasks.add(cheTasks.debugTask(flags));
            try {
                yield tasks.run(ctx);
                this.log(`CodeReady Workspaces server debug is available on localhost:${flags['debug-port']}.`);
                this.log('The program keeps running to enable port forwarding.');
            }
            catch (error) {
                this.error(error);
            }
        });
    }
}
exports.default = Debug;
Debug.description = 'Enable local debug of CodeReady Workspaces server';
Debug.flags = {
    help: command_1.flags.help({ char: 'h' }),
    chenamespace: common_flags_1.cheNamespace,
    'listr-renderer': common_flags_1.listrRenderer,
    'debug-port': flags_1.integer({
        description: 'CodeReady Workspaces server debug port',
        default: 8000
    }),
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck
};
//# sourceMappingURL=debug.js.map

==> codeready-workspaces-2.12.0-GA-crwctl-sources.tar.gz: crwctl/lib/commands/server/debug.js <==
"use strict";
/**
 * Copyright (c) 2019-2021 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const flags_1 = require("@oclif/parser/lib/flags");
const Listr = require("listr");
const context_1 = require("../../api/context");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
const che_1 = require("../../tasks/che");
const api_1 = require("../../tasks/platforms/api");
const util_1 = require("../../util");
class Debug extends command_1.Command {
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Debug);
            flags.chenamespace = yield util_1.findWorkingNamespace(flags);
            const ctx = yield context_1.ChectlContext.initAndGet(flags, this);
            yield this.config.runHook(constants_1.DEFAULT_ANALYTIC_HOOK_NAME, { command: Debug.id, flags });
            const cheTasks = new che_1.CheTasks(flags);
            const apiTasks = new api_1.ApiTasks();
            const tasks = new Listr([], { renderer: flags['listr-renderer'] });
            tasks.add(apiTasks.testApiTasks(flags));
            tasks.add(cheTasks.verifyCheNamespaceExistsTask(flags, this));
            tasks.add(cheTasks.debugTask(flags));
            try {
                yield tasks.run(ctx);
                this.log(`CodeReady Workspaces server debug is available on localhost:${flags['debug-port']}.`);
                this.log('The program keeps running to enable port forwarding.');
            }
            catch (err) {
                this.error(util_1.wrapCommandError(err));
            }
        });
    }
}
exports.default = Debug;
Debug.description = 'Enable local debug of CodeReady Workspaces server';
Debug.flags = {
    help: command_1.flags.help({ char: 'h' }),
    chenamespace: common_flags_1.cheNamespace,
    'listr-renderer': common_flags_1.listrRenderer,
    'debug-port': flags_1.integer({
        description: 'CodeReady Workspaces server debug port',
        default: 8000,
    }),
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck,
    telemetry: common_flags_1.CHE_TELEMETRY,
};
//# sourceMappingURL=debug.js.map
